div.bg-image {
  position: fixed;
  height: 100%;
  width: 100%;
  padding: 0;
  margin: 0;
  top: 0;
  left: 0;
  background-image: url(../background.png);
  background-position: center center;
  background-repeat: no-repeat;
  background-size: cover;
  opacity: 0.3;
  z-index: -1000;
}

div.container {
  margin-top: 40px;
  margin-bottom: 40px;
}

.form-signin {
  max-width: 530px;
  padding: 15px;
  margin: 0 auto;
}
.form-or-heading {
  text-align: center;
}
.form-signin h5 {
  padding-left: 8em;
}
.form-signin .form-signin-heading,
.form-signin .checkbox {
  margin-bottom: 10px;
}
.form-signin .checkbox,
.form-signin .radiobox {
  font-weight: normal;
}
.form-signin .form-control {
  position: relative;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  font-size: 16px;
  max-width: 16em;
}
.form-signin .form-control.command {
  margin-left: 1.6em;
}
.form-signin .form-control:focus {
  z-index: 2;
}
.form-signin .panel-group {
  padding-top: 8px;
}

.form-signin .security-box {
  padding-left: 5em;
}
.form-signin .security-box #key {
  font-size: 12px;
  padding: 0px 10px;
  height: 20px;
}

.form-signin .list-group-item {
  padding: 6px 10px;
}

.form-signin .list-style-none {
  list-style-type: none;
  margin-bottom: 5px;
}
.form-signin .action input {
  font-size: 12px;
  padding: 2px;
}

.form-signin img.command-icon {
  object-fit: scale-down;
  max-width: 32px;
  max-height: 32px;
}
.form-signin span.warning {
  color: red;
  font-size: smaller;
  padding-left: 10px;
}
.form-signin span.disabled {
  color: grey;
}

.form-signin img.field-icon {
  margin-left: -32px;
  position: relative;
  z-index: 2;
  font-family: bootstrap-icons;
  width: 1.2em;
  height: 1.2em;
}
