var XpraOffscreenWorker={isAvailable(){if(XpraImageDecoderLoader.hasNativeDecoder()&&XpraVideoDecoderLoader.hasNativeDecoder&&"undefined"!=typeof OffscreenCanvas)try{return new OffscreenCanvas(256,256),!0}catch(error){console.warn("unable to instantiate an offscreen canvas:",error)}return console.warn("Offscreen decoding is not available. Please consider using Google Chrome 94+ in a secure (SSL or localhost) context for better performance."),!1}};